def ignore_lines(string):
    def _strip(lines):
        for l in lines:
            yield l.strip()

    if result := "\n".join(
        [
            line
            for line in _strip(string.split("\n"))
            if line and not line.startswith("#")
        ]
    ):
        return result



from pathlib import PurePath, Path

from setuptools import setup
from setuptools import find_packages

_HERE = PurePath(__file__).parent
_PATH_VERSION = Path() / _HERE / "snippet" / "__version__.py"

about = {}
with open(_PATH_VERSION) as file:
    exec(file.read(), about)

setup(
    name=about["__title__"],
    version=about["__version__"],
    description=about["__description__"],
    url="https://github.com/foxyblue/snippet",
    author="S. Williams-Wynn",
    author_email="s.williamswynn.mail@gmail.com",
    packages=find_packages(include=["snippet"]),
    entry_points={'console_scripts': ["snip=snippet.cmd:main"]},
    install_requires=["click", "vim-edit"],
    python_requires=">=3.6",
)



import os
import ast
import glob
from pathlib import PurePath
from datetime import datetime


_WARNING = "\033[93m"
_ENDC = "\033[0m"


class Info:
    def __init__(self, snippet: str):
        self.name = snippet

        with open(snippet) as file:
            content = file.read()

        self.header = ast.get_docstring(ast.parse(content))
        timestamp = os.stat(snippet).st_birthtime
        self.created = datetime.utcfromtimestamp(timestamp).strftime(
            "%Y-%m-%d %H:%M:%S"
        )

    def __str__(self):
        return f"{_WARNING}=> {self.name} - {self.created}{_ENDC}\n{self.header}\n"

    def todict(self):
        return {
            "name": self.name,
            "created": self.created,
            "header": self.header,
        }


class Tracker:
    """Should I manage snippets in a separate dir?"""

    pattern = "snippet*.py"

    def __init__(self):
        self.dir = PurePath(os.getcwd())
        self.count = self.total_snippets()

    def next_snippet(self):
        self.count += 1
        return f"snippet{self.count}.py"

    def snippet(self):
        return f"snippet{self.count}.py"

    def snippet_info(self, snippet: str):
        """Returns info on snippet.

        :param snippet: Name of snippet.
        """
        return Info(snippet)

    def total_snippets(self):
        """ Count 'snippet\\d.py' in current dir."""
        return len(self.snippets())

    def snippets(self):
        return glob.glob(self.pattern)
